@@ -1,22 +1,15 @@
-"""
-
-License: http://www.stsci.edu/resources/software_hardware/pyraf/LICENSE
-
-"""
-from __future__ import division # confidence high
-
 from astropy.io import fits
 
 __version__ = '0.3 (01-July-2014)'
 
 
-class IterFitsFile(object):
+class IterFitsFile:
     """ This class defines an object which can be used to
         access the data from a FITS file without leaving
         the file-handle open between reads.
 
     """
-    def __init__(self,name):
+    def __init__(self, name):
         self.name = name
         self.fname = None
         self.extn = None
@@ -29,7 +22,8 @@ class IterFitsFile(object):
 
     def set_inmemory(self,val):
         """Sets inmemory attribute to either True or False """
-        assert type(val) is bool, 'Please specify either True or False'
+        if type(val) is not bool:
+            raise TypeError('Input value must be boolean')
         self.inmemory = val
 
     def _shape(self):
